==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Information/InfoDistanceEE/ts/InfoDistanceEE_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>InfoDistanceEE</name>
    <message>
        <location filename="../InfoDistanceEE.js" line="+62"/>
        <source>Specify first entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Specify second entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation type="unfinished">Zrobione</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Distance:</source>
        <translation type="unfinished">Odległość:</translation>
    </message>
    <message>
        <location filename="../InfoDistanceEEInit.js" line="+2"/>
        <source>Distance &amp;Entity to Entity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InfoDistanceEP</name>
    <message>
        <source>Specify entity</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wprowadź obiekt
Wskaż obiekt do cięcia</translatorcomment>
        <translation type="obsolete">Wprowadź obiekt</translation>
    </message>
    <message>
        <source>Specify point</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż punkt</translatorcomment>
        <translation type="obsolete">Wskaż punkt</translation>
    </message>
    <message>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation type="obsolete">Zrobione</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Odległość: %1
Zaznacz obiekt do przycięcia lub wprowadź odległość:</translatorcomment>
        <translation type="obsolete">Odległość:</translation>
    </message>
    <message>
        <source>Distance &amp;Entity to Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Podmiot odległość do punktu</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Information/InfoDistanceEE/ts/InfoDistanceEE_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>InfoDistanceEE</name>
    <message>
        <location filename="../InfoDistanceEE.js" line="+62"/>
        <source>Specify first entity</source>
        <translation>Proszę wskazać pierwszy obiekt</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Specify second entity</source>
        <translation>Proszę wskazać drugi obiekt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>Zrobione</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Distance:</source>
        <translation>Odległość:</translation>
    </message>
    <message>
        <location filename="../InfoDistanceEEInit.js" line="+2"/>
        <source>Distance &amp;Entity to Entity</source>
        <translation>Odległość &amp;obiektu do obiektu</translation>
    </message>
</context>
<context>
    <name>InfoDistanceEP</name>
    <message>
        <source>Specify entity</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wprowadź obiekt
Wskaż obiekt do cięcia</translatorcomment>
        <translation type="obsolete">Wprowadź obiekt</translation>
    </message>
    <message>
        <source>Specify point</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
Wskaż punkt</translatorcomment>
        <translation type="obsolete">Wskaż punkt</translation>
    </message>
    <message>
        <source>Done</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Zrobione.
Zrobione
&amp;Zrobione i do następnego</translatorcomment>
        <translation type="obsolete">Zrobione</translation>
    </message>
    <message>
        <source>Distance:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Odległość: %1
Zaznacz obiekt do przycięcia lub wprowadź odległość:</translatorcomment>
        <translation type="obsolete">Odległość:</translation>
    </message>
    <message>
        <source>Distance &amp;Entity to Point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Podmiot odległość do punktu</translation>
    </message>
</context>
</TS>
